package com.supervision.pdfqaserver.service;

import com.supervision.pdfqaserver.dto.CypherSchemaDTO;
import com.supervision.pdfqaserver.dto.DomainMetadataDTO;
import com.supervision.pdfqaserver.dto.EREDTO;
import java.util.List;
import java.util.Map;

/**
 * 三元组转换为Cypher语句的执行器
 */
public interface TripleToCypherExecutor {

    /**
     * 生成Cypher语句
     * @param eredto
     * @return
     */
    String generateInsertCypher(EREDTO eredto);



    /**
     * 生成查询Cypher语句
     * @param query 用户查询语句
     * @param domainCategoryId 领域分类ID
     * @return
     */
    String generateQueryCypher(String query,String domainCategoryId);

    /**
     * 执行Cypher语句
     * @param cypher
     * @return
     */
    List<Map<String, Object>> executeCypher(String cypher);

    Map<String, List<Map<String, Object>>> executeCypher(List<String> cypher);

    void saveERE(EREDTO eredto);


    /**
     * 加载图谱的schema
     */
    CypherSchemaDTO loadGraphSchema();

    /**
     * 刷新图谱的schema分词向量
     */
    void refreshSchemaSegmentVector();


    /**
     * 根据领域元数据查询关联的关系图谱的schema
     * @param metadataDTOS 领域元数据列表
     * @return
     */
    CypherSchemaDTO queryRelationSchema(List<DomainMetadataDTO> metadataDTOS);


    /**
     * 查询关系图谱的schema
     * @param query 用户查询语句
     * @return schema
     */
    CypherSchemaDTO queryRelationSchema(String query);

}
