package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.NodeRelationVector;
import com.supervision.pdfqaserver.dto.*;
import com.supervision.pdfqaserver.service.AiCallService;
import com.supervision.pdfqaserver.service.NodeRelationVectorService;
import com.supervision.pdfqaserver.mapper.NodeRelationVectorMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.ai.embedding.Embedding;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import java.util.ArrayList;
import java.util.List;

/**
* @author Administrator
* @description 针对表【node_relation_vector(节点关系向量表)】的数据库操作Service实现
* @createDate 2025-06-18 13:38:02
*/
@Slf4j
@Service
@RequiredArgsConstructor
public class NodeRelationVectorServiceImpl extends ServiceImpl<NodeRelationVectorMapper, NodeRelationVector>
    implements NodeRelationVectorService{

    private final AiCallService aiCallService;
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void refreshSchemaSegmentVector(CypherSchemaDTO cypherSchemaDTO) {

        // 删除旧的向量数据
        super.lambdaUpdate().remove();
        // 重新插入新的向量数据
        List<EntityExtractionDTO> nodes = cypherSchemaDTO.getNodes();
        List<RelationExtractionDTO> relations = cypherSchemaDTO.getRelations();
        List<NodeRelationVector> allRelationVectors = new ArrayList<>();
        List<String> texts = new ArrayList<>();
        for (List<RelationExtractionDTO> relationSplit : CollUtil.split(relations, 200)) {
            List<String> rs = relationSplit.stream().map(RelationExtractionDTO::getRelation).toList();
            List<Embedding> embedding = aiCallService.embedding(rs);
            for (Embedding embed : embedding) {
                if (texts.contains(rs.get(embed.getIndex()))){
                    continue;
                }
                texts.add(rs.get(embed.getIndex()));
                NodeRelationVector vector = new NodeRelationVector();
                vector.setContent(rs.get(embed.getIndex()));
                vector.setEmbedding(embed.getOutput());
                vector.setContentType("R");// 关系
                allRelationVectors.add(vector);
            }
            List<String> ers = relationSplit.stream()
                    .map(r -> StrUtil.join(" ", r.getSourceType(), r.getRelation(),r.getTargetType())).toList();
            List<Embedding> erEmbeddings = aiCallService.embedding(ers);
            for (Embedding embed : erEmbeddings) {
                if (texts.contains(ers.get(embed.getIndex()))) {
                    continue;
                }
                texts.add(ers.get(embed.getIndex()));
                NodeRelationVector vector = new NodeRelationVector();
                vector.setContent(ers.get(embed.getIndex()));
                vector.setEmbedding(embed.getOutput());
                vector.setContentType("ER");
                allRelationVectors.add(vector);
            }
        }
        super.saveBatch(allRelationVectors);
        List<NodeRelationVector> allNodeVectors = new ArrayList<>();
        texts = new ArrayList<>();
        for (List<EntityExtractionDTO> entitySplit : CollUtil.split(nodes, 200)) {
            List<String> es = entitySplit.stream().map(EntityExtractionDTO::getEntity).toList();
            List<Embedding> embedding = aiCallService.embedding(es);
            for (Embedding embed : embedding) {
                if (texts.contains(es.get(embed.getIndex()))) {
                    continue;
                }
                texts.add(es.get(embed.getIndex()));
                NodeRelationVector vector = new NodeRelationVector();
                vector.setContent(es.get(embed.getIndex()));
                vector.setEmbedding(embed.getOutput());
                vector.setContentType("N");
                allNodeVectors.add(vector);
            }
        }
        super.saveBatch(allNodeVectors);
    }

    @Override
    public List<NodeRelationVector> matchSimilarByCosine(float[] embedding, double threshold, List<String> contentType, int limit) {
        return super.getBaseMapper().findSimilarByCosine(embedding, threshold, contentType, limit);
    }

    @Override
    public Double matchContentScore(float[] embedding, String content) {
        if (StrUtil.isEmpty(content) || embedding == null || embedding.length == 0) {
            return 0.0;
        }
        return super.getBaseMapper().matchContentScore(embedding, content);
    }
}




