package com.supervision.pdfqaserver.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.pdfqaserver.domain.QuestionCategory;
import com.supervision.pdfqaserver.domain.QuestionHandlerMapping;
import com.supervision.pdfqaserver.service.QuestionCategoryService;
import com.supervision.pdfqaserver.service.QuestionHandlerMappingService;
import com.supervision.pdfqaserver.mapper.QuestionHandlerMappingMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
* @author Administrator
* @description 针对表【question_handler_mapping(问题处理器映射表)】的数据库操作Service实现
* @createDate 2025-06-13 11:29:01
*/
@Slf4j
@Service
@RequiredArgsConstructor
public class QuestionHandlerMappingServiceImpl extends ServiceImpl<QuestionHandlerMappingMapper, QuestionHandlerMapping>
    implements QuestionHandlerMappingService{

    private final QuestionCategoryService categoryService;

    @Override
    public QuestionHandlerMapping findHandlerByCategoryId(String categoryId) {

        while (true){
            if (StrUtil.isEmpty(categoryId)) {
                return null;
            }
            QuestionHandlerMapping one = super.lambdaQuery().eq(QuestionHandlerMapping::getQuestionCategoryId, categoryId).one();
            if (null == one){
                log.info("根据分类id:{}未找到处理器映射，尝试查询分类器上级关联数据", categoryId);
                QuestionCategory category = categoryService.findCategoryById(categoryId);
                if (StrUtil.isEmpty(category.getParentId())) {
                    log.info("分类id:{} 没有父级id，不进行查询", categoryId);
                    return null;
                }else {
                    log.info("分类id:{} 的父级id为:{}", categoryId, category.getParentId());
                    categoryId = category.getParentId();
                    continue;
                }
            }
            return one;
        }
    }
}




